@@ -2,11 +2,12 @@
 """
 @Author: CaiYouBin
 @Date: 2020-05-12 20:04:54
-@LastEditTime: 2020-12-07 18:14:22
+@LastEditTime: 2020-12-24 18:00:54
 @LastEditors: HuangJingCan
 @Description: 基础接口
 """
 import random
+from copy import deepcopy
 from seven_cloudapp.handlers.seven_base import *
 from seven_framework.qr_code import *
 
@@ -198,6 +199,7 @@ class ActHandler(SevenBaseHandler):
         @param close_word：关闭小程序文案
         @param share_desc：分享内容
         @param rule_desc：规则内容
+        @param integral_rule：积分规则
         @param start_date：开始时间
         @param end_date：结束时间
         @param refund_count：退款次数
@@ -221,6 +223,7 @@ class ActHandler(SevenBaseHandler):
         close_word = self.get_param("close_word", "抱歉，程序维护中")
         share_desc = self.get_param("share_desc")
         rule_desc = self.get_param("rule_desc")
+        integral_rule = self.get_param("integral_rule")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
         refund_count = int(self.get_param("refund_count", 0))
@@ -236,7 +239,7 @@ class ActHandler(SevenBaseHandler):
         if act_id > 0:
             act_info = act_info_model.get_entity_by_id(act_id)
 
-            old_act_info = copy.deepcopy(act_info)
+            old_act_info = deepcopy(act_info)
 
             act_info.act_name = act_name
             act_info.theme_id = theme_id
@@ -244,8 +247,9 @@ class ActHandler(SevenBaseHandler):
             act_info.close_word = close_word
             act_info.share_desc = share_desc if share_desc != "" else []
             act_info.rule_desc = rule_desc if rule_desc != "" else []
-            act_info.start_date = start_date
-            act_info.end_date = end_date
+            act_info.integral_rule = integral_rule if integral_rule != "" else []
+            act_info.start_date = start_date if start_date else "1900-01-01 00:00:00"
+            act_info.end_date = end_date if end_date else "2900-01-01 00:00:00"
             act_info.refund_count = refund_count
             act_info.is_black = is_black
             act_info.sort_index = sort_index
@@ -293,11 +297,11 @@ class ActListHandler(SevenBaseHandler):
             page_list, total = ActInfoModel().get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)
 
             for page in page_list:
-                page["share_desc"] = json.loads(page["share_desc"]) if page["share_desc"] else []
-                page["rule_desc"] = json.loads(page["rule_desc"]) if page["rule_desc"] else []
-                page["menu_configed"] = json.loads(page["menu_configed"]) if page["menu_configed"] else []
-                page["online_url"] = f"https://m.duanqu.com/?_ariver_appid={app_id}&query=" + CodingHelper.url_encode(f"actid={page['id']}")
-                page["live_url"] = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
+                page["share_desc"] = self.json_loads(page["share_desc"]) if page["share_desc"] else []
+                page["rule_desc"] = self.json_loads(page["rule_desc"]) if page["rule_desc"] else []
+                page["menu_configed"] = self.json_loads(page["menu_configed"]) if page["menu_configed"] else []
+                page["online_url"] = self.get_online_url(page['id'], app_id)
+                page["live_url"] = self.get_live_url(app_id)
 
             page_info = PageInfo(page_index, page_size, total, page_list)
 
@@ -323,11 +327,11 @@ class ActInfoHandler(SevenBaseHandler):
         act_info = ActInfoModel().get_entity_by_id(act_id)
 
         if act_info:
-            act_info.share_desc = json.loads(act_info.share_desc) if act_info.share_desc != "" else []
-            act_info.rule_desc = json.loads(act_info.rule_desc) if act_info.rule_desc != "" else []
-            act_info.menu_configed = json.loads(act_info.menu_configed) if act_info.menu_configed != "" else []
-            act_info.online_url = f"https://m.duanqu.com/?_ariver_appid={act_info.app_id}&query=" + CodingHelper.url_encode(f"actid={act_info.id}")
-            act_info.live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={act_info.app_id}"
+            act_info.share_desc = self.json_loads(act_info.share_desc) if act_info.share_desc != "" else []
+            act_info.rule_desc = self.json_loads(act_info.rule_desc) if act_info.rule_desc != "" else []
+            act_info.menu_configed = self.json_loads(act_info.menu_configed) if act_info.menu_configed != "" else []
+            act_info.online_url = self.get_online_url(act_info.id, act_info.app_id)
+            act_info.live_url = self.get_live_url(act_info.app_id)
 
             self.reponse_json_success(act_info)
         else:
@@ -434,7 +438,7 @@ class NextProgressHandler(SevenBaseHandler):
         if not act_info:
             return self.reponse_json_error("NoAct", "对不起，找不到当前活动")
 
-        menu_config = json.loads(base_info.menu_config)
+        menu_config = self.json_loads(base_info.menu_config)
         menu = [menu for menu in menu_config if menu["key"] == finish_key]
         if len(menu) == 0:
             return self.reponse_json_error("Error", "对不起，无此菜单")
@@ -445,7 +449,7 @@ class NextProgressHandler(SevenBaseHandler):
         if act_info.menu_configed == "":
             act_info.menu_configed = "[]"
 
-        menu_configed = json.loads(act_info.menu_configed)
+        menu_configed = self.json_loads(act_info.menu_configed)
         menu_configed.append(finish_key)
 
         result_menu_configed = []
