@@ -2,7 +2,7 @@
 """
 @Author: HuangJingCan
 @Date: 2020-06-02 11:08:39
-@LastEditTime: 2020-12-07 17:01:12
+@LastEditTime: 2020-12-18 14:10:04
 @LastEditors: HuangJingCan
 @Description: 订单相关
 """
@@ -280,34 +280,30 @@ class PrizeOrderExportHandler(SevenBaseHandler):
         @param order_no：订单号
         @param order_status：订单状态
         @param nick_name：用户昵称
+        @param is_machine：是否机台
         @return str
         @last_editors: HuangJingCan
         """
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
         act_id = self.get_param("act_id")
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
         user_nick = self.get_param("nick_name")
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 500))
+        is_machine = int(self.get_param("is_machine", 0))
 
         condition = "act_id=%s"
         params = [act_id]
 
         if order_no != "":
             params.append(order_no)
-            condition = "order_no=%s"
+            condition += " AND order_no=%s"
         if user_nick != "":
             params.append(user_nick)
-            if condition == "":
-                condition = "user_nick=%s"
-            else:
-                condition += " AND user_nick=%s"
+            condition += " AND user_nick=%s"
         if order_status >= 0:
             params.append(order_status)
-            if condition == "":
-                condition = "order_status=%s"
-            else:
-                condition += " AND order_status=%s"
+            condition += " AND order_status=%s"
 
         #奖品订单
         prize_order_list_dict, total = PrizeOrderModel().get_dict_page_list("*", page_index, page_size, condition, "", "create_date desc", params)
@@ -326,8 +322,9 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                     data_row["小程序订单号"] = prize_order["order_no"]
                     data_row["淘宝子订单号"] = prize_roster["order_no"]
                     data_row["淘宝名"] = prize_order["user_nick"]
-                    data_row["盒子名称"] = prize_roster["machine_name"]
-                    data_row["盒子价格"] = str(prize_roster["machine_price"])
+                    if is_machine == 1:
+                        data_row["盒子名称"] = prize_roster["machine_name"]
+                        data_row["盒子价格"] = str(prize_roster["machine_price"])
                     data_row["奖品名称"] = prize_roster["prize_name"]
                     data_row["商家编码"] = prize_roster["goods_code"]
                     data_row["姓名"] = prize_order["real_name"]
@@ -446,34 +443,30 @@ class PrizeRosterExportHandler(SevenBaseHandler):
         @param order_no：订单号
         @param order_status：订单状态
         @param nick_name：用户昵称
-        @return 字符串
+        @param is_machine：是否机台
+        @return str
         @last_editors: HuangJingCan
         """
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 500))
         act_id = self.get_param("act_id")
         order_no = self.get_param("order_no")
         order_status = int(self.get_param("order_status", -1))
         user_nick = self.get_param("nick_name")
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 500))
+        is_machine = int(self.get_param("is_machine", 0))
 
         condition = "act_id=%s"
         params = [act_id]
 
         if order_no != "":
             params.append(order_no)
-            condition = "order_no=%s"
+            condition += " AND order_no=%s"
         if user_nick != "":
             params.append(user_nick)
-            if condition == "":
-                condition = "user_nick=%s"
-            else:
-                condition += " AND user_nick=%s"
+            condition += " AND user_nick=%s"
         if order_status >= 0:
             params.append(order_status)
-            if condition == "":
-                condition = "order_status=%s"
-            else:
-                condition += " AND order_status=%s"
+            condition += " AND order_status=%s"
 
         #奖品订单
         prize_roster_list, total = PrizeRosterModel().get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
@@ -485,8 +478,9 @@ class PrizeRosterExportHandler(SevenBaseHandler):
             data_row["行为编号"] = prize_roster["id"]
             data_row["淘宝子订单号"] = prize_roster["order_no"]
             data_row["淘宝名"] = prize_roster["user_nick"]
-            data_row["盒子名称"] = prize_roster["machine_name"]
-            data_row["盒子价格"] = str(prize_roster["machine_price"])
+            if is_machine == 1:
+                data_row["盒子名称"] = prize_roster["machine_name"]
+                data_row["盒子价格"] = str(prize_roster["machine_price"])
             data_row["奖品名称"] = prize_roster["prize_name"]
             data_row["奖品价值"] = str(prize_roster["prize_price"])
             data_row["SKU"] = prize_roster["properties_name"]
@@ -503,7 +497,7 @@ class PrizeRosterExportHandler(SevenBaseHandler):
             path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
             ExcelHelper.export(result_data, path)
 
-            resource_path = OSS2Helper().upload("", path, "test", False)
+            resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)
 
             os.remove(path)
 
