@@ -2,7 +2,7 @@
 """
 @Author: HuangJingCan
 @Date: 2020-08-12 09:06:24
-@LastEditTime: 2020-12-09 15:38:56
+@LastEditTime: 2020-12-24 17:57:07
 @LastEditors: HuangJingCan
 @Description: 淘宝top接口基础类
 """
@@ -39,7 +39,8 @@ class TopBaseHandler(SevenBaseHandler):
                 else:
                     prize = ActPrizeModel().get_entity("goods_id=%s and sku_detail<>'' and is_sku=1 ", params=int(num_iids))
                     if prize:
-                        sku_detail = json.loads(prize.sku_detail.replace('\'', '\"'))
+                        # sku_detail = json.loads(prize.sku_detail.replace('\'', '\"'))
+                        sku_detail = self.json_loads(prize.sku_detail)
                         return self.reponse_json_success(sku_detail["items_seller_list_get_response"])
                     else:
                         return self.reponse_json_error("NoSku", "对不起，找不到该商品的sku")
@@ -179,6 +180,114 @@ class TopBaseHandler(SevenBaseHandler):
         ]
         return status
 
+    def instantiate_new(self, description, icon):
+        """
+        @description: 实例化
+        @param description：活动简介
+        @param icon：活动图标
+        @return app_info
+        @last_editors: HuangJingCan
+        """
+        app_name = config.get_value("project_name")
+        template_id = config.get_value("client_template_id")
+        template_version = ""
+        access_token = self.get_taobao_param().access_token
+        user_nick = self.get_taobao_param().user_nick
+        if not user_nick:
+            return self.reponse_json_error("Error", "对不起,请先授权登录")
+        open_id = self.get_taobao_param().open_id
+        store_user_nick = user_nick.split(':')[0]
+        if not store_user_nick:
+            return self.reponse_json_error("Error", "对不起，请先授权登录")
+        app_info_model = AppInfoModel()
+        store_user_nick = user_nick.split(':')[0]
+        app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
+        # 有效时间获取
+        dead_date = self.get_dead_date(store_user_nick)
+        if app_info:
+            if dead_date != "expire":
+                app_info.expiration_date = dead_date
+            access_token = self.get_token()
+            if access_token != "":
+                app_info.access_token = access_token
+            app_info_model.update_entity(app_info, "expiration_date,access_token")
+            return self.reponse_json_success({"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token})
+        else:
+            # 记得删除过审核后
+            # return self.reponse_json_success({"app_id": "112233445566", "store_user_nick": "西红柿炒蛋889", "user_nick": "西红柿炒蛋889", "access_token": "50000400807diMFrvoI14d2fae2PaOPg86ivFqRczOkBbAw5MyWDohSIZSfhw2L7ASf"})
+            if self.get_is_test():
+                return self.reponse_json_success()
+            if ":" in user_nick:
+                return self.reponse_json_error("Error", "对不起，初次创建活动包含实例化，请试用主账号进行创建。")
+            base_info = BaseInfoModel().get_entity()
+            template_version = base_info.client_ver
+
+        try:
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.MiniappTemplateInstantiateRequest()
+
+            req.clients = "taobao,tmall"
+            req.description = description
+            shop_info = self.get_shop(access_token)
+
+            # self.logger_info.info("【实例化名称】" + ":" + str(app_name))
+            req.ext_json = "{ \"name\":\"" + app_name + "\"}"
+            req.icon = icon
+            req.alias = app_name
+            req.template_id = template_id
+            req.template_version = template_version
+            resp = req.getResponse(access_token)
+
+            #录入数据库
+            result_app = resp["miniapp_template_instantiate_response"]
+            app_info = AppInfo()
+            app_info.clients = req.clients
+            app_info.app_desc = result_app["app_description"]
+            app_info.app_icon = result_app["app_icon"]
+            app_info.app_id = result_app["app_id"]
+            app_info.app_name = result_app["app_name"]
+            app_info.app_ver = result_app["app_version"]
+            app_info.app_key = result_app["appkey"]
+            app_info.preview_url = result_app["pre_view_url"]
+            app_info.template_id = req.template_id
+            app_info.template_ver = req.template_version
+            app_info.access_token = access_token
+
+            if "shop_seller_get_response" in shop_info.keys():
+                app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
+                app_info.store_id = shop_info["shop_seller_get_response"]["shop"]["sid"]
+
+            user_seller = self.get_user_seller(access_token)
+            if "user_seller_get_response" in user_seller.keys():
+                app_info.seller_id = user_seller["user_seller_get_response"]["user"]["user_id"]
+
+            app_info.is_instance = 1
+            app_info.store_user_nick = store_user_nick
+            app_info.owner_open_id = open_id
+            app_info.instance_date = self.get_now_datetime()
+            app_info.modify_date = self.get_now_datetime()
+            #上线
+            online_app_info = self.online_app(app_info.app_id, template_id, template_version, app_info.app_ver, access_token)
+            if "miniapp_template_onlineapp_response" in online_app_info.keys():
+                app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]
+
+            app_info.id = app_info_model.add_entity(app_info)
+
+            self.create_operation_log(OperationType.add.value, app_info.__str__(), "instantiate_app", None, self.json_dumps(app_info))
+
+            return self.reponse_json_success({"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token})
+        except Exception as ex:
+            self.logger_error.error(str(ex))
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=" in content:
+                        if "名称已经存在" in content:
+                            return self.reponse_json_error("CreateError", content[len("submsg="):], {"icon": icon, "app_name": app_name})
+                        if "应用名称不合法" in content:
+                            return self.reponse_json_error("CreateError", content[len("submsg="):], {"icon": icon, "app_name": app_name})
+                        return self.reponse_json_error("CreateError", content[len("submsg="):], {"icon": icon, "app_name": app_name})
+
     def instantiate(self, user_nick, act_name, description, icon, name_ending):
         """
         @description: 实例化
@@ -676,6 +785,34 @@ class TopBaseHandler(SevenBaseHandler):
             return resp
         except Exception as ex:
             # self.logger_info.info(str(ex) + "【access_token】：" + self.get_taobao_param().access_token)
+            if "submsg" in str(ex):
+                content_list = str(ex).split()
+                for content in content_list:
+                    if "submsg=该子帐号无此操作权限" in content:
+                        return self.reponse_json_error("NoPower", content[len("submsg="):])
+                    if "submsg=" in content:
+                        return self.reponse_json_error("Error", content[len("submsg="):])
+
+    def get_coupon_details(self, right_ename):
+        """
+        @description: 获取优惠券详情信息(请求top接口)
+        @param right_ename:奖池ID
+        @return: dict
+        @last_editors: LaiKaiXiang
+        """
+        right_ename = self.get_param("right_ename")
+        access_token = self.get_taobao_param().access_token
+        resp = ""
+        try:
+            top.setDefaultAppInfo(config.get_value("app_key"), config.get_value("app_secret"))
+            req = top.api.AlibabaBenefitQueryRequest()
+            req.ename = right_ename
+            req.app_name = "promotioncenter-" + config.get_value("server_template_id")
+            req.award_type = "1"
+            resp = req.getResponse(access_token)
+            return resp
+        except Exception as ex:
+            # self.logger_error.error(str(ex) + "【获取优惠券详情信息】")
             if "submsg" in str(ex):
                 content_list = str(ex).split()
                 for content in content_list:
